# This file was auto-generated by Fern from our API Definition.

import typing

StreamTtsRequestMessageLanguage = typing.Union[
    typing.Literal["en", "hi", "mr", "kn", "ta", "bn", "gu", "de", "fr", "es", "it", "pl", "nl", "ru", "ar", "he"],
    typing.Any,
]
