# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.serialization import FieldMetadata
from ....core.unchecked_base_model import UncheckedBaseModel


class GetUserResponseData(UncheckedBaseModel):
    id: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="_id"), pydantic.Field(alias="_id", description="The ID of the user")
    ] = None
    first_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="firstName"),
        pydantic.Field(alias="firstName", description="The first name of the user"),
    ] = None
    last_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="lastName"),
        pydantic.Field(alias="lastName", description="The last name of the user"),
    ] = None
    user_email: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="userEmail"),
        pydantic.Field(alias="userEmail", description="The email of the user"),
    ] = None
    auth_provider: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="authProvider"),
        pydantic.Field(alias="authProvider", description="The authentication provider of the user"),
    ] = None
    is_email_verified: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="isEmailVerified"),
        pydantic.Field(alias="isEmailVerified", description="Whether the user's email is verified"),
    ] = None
    organization_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="organizationId"),
        pydantic.Field(alias="organizationId", description="The organization ID of the user"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
