# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .create_agent_request_language_enabled import CreateAgentRequestLanguageEnabled
from .create_agent_request_language_switching import CreateAgentRequestLanguageSwitching


class CreateAgentRequestLanguage(UncheckedBaseModel):
    """
    Language configuration for the agent. You can enable or disable language switching for the agent. This will be used to determine the language of the agent.
    """

    enabled: typing.Optional[CreateAgentRequestLanguageEnabled] = pydantic.Field(default=None)
    """
    The language of the agent. Supported: 'en' (English), 'hi' (Hindi), 'ta' (Tamil).
    """

    switching: typing.Optional[CreateAgentRequestLanguageSwitching] = pydantic.Field(default=None)
    """
    Language switching configuration for the agent. If enabled, the agent will be able to switch between languages based on the user's language.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
