# This file was auto-generated by Fern from our API Definition.

import typing

CreateAgentRequestSynthesizerVoiceConfigGenderModel = typing.Union[
    typing.Literal["waves_lightning_large_voice_clone"], typing.Any
]
