# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.serialization import FieldMetadata
from ....core.unchecked_base_model import UncheckedBaseModel
from .get_conversation_response_data_disposition_metrics_config_item import (
    GetConversationResponseDataDispositionMetricsConfigItem,
)
from .get_conversation_response_data_logs_item import GetConversationResponseDataLogsItem
from .get_conversation_response_data_pagination import GetConversationResponseDataPagination


class GetConversationResponseData(UncheckedBaseModel):
    logs: typing.Optional[typing.List[GetConversationResponseDataLogsItem]] = None
    pagination: typing.Optional[GetConversationResponseDataPagination] = None
    disposition_metrics_config: typing_extensions.Annotated[
        typing.Optional[typing.List[GetConversationResponseDataDispositionMetricsConfigItem]],
        FieldMetadata(alias="dispositionMetricsConfig"),
        pydantic.Field(alias="dispositionMetricsConfig", description="Global disposition metrics configuration"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
