# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations


class SmallestAIEnvironment:
    PRODUCTION: SmallestAIEnvironment

    def __init__(self, *, atoms: str, waves: str, waves_ws: str):
        self.atoms = atoms
        self.waves = waves
        self.waves_ws = waves_ws


SmallestAIEnvironment.PRODUCTION = SmallestAIEnvironment(
    atoms="https://api.smallest.ai/atoms/v1",
    waves="https://waves-api.smallest.ai",
    waves_ws="wss://waves-api.smallest.ai",
)
