# This file was auto-generated by Fern from our API Definition.

import typing

LightningSpeechToTextRequestLanguage = typing.Union[
    typing.Literal[
        "it",
        "es",
        "en",
        "pt",
        "hi",
        "de",
        "fr",
        "uk",
        "ru",
        "kn",
        "ml",
        "pl",
        "mr",
        "gu",
        "cs",
        "sk",
        "te",
        "or",
        "nl",
        "bn",
        "lv",
        "et",
        "ro",
        "pa",
        "fi",
        "sv",
        "bg",
        "ta",
        "hu",
        "da",
        "lt",
        "mt",
        "multi",
    ],
    typing.Any,
]
