# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ..types.lightningv2request_language import Lightningv2RequestLanguage
from ..types.lightningv2request_output_format import Lightningv2RequestOutputFormat
from ..types.sample_rate import SampleRate
from .raw_client import AsyncRawLightningV2Client, RawLightningV2Client

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class LightningV2Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawLightningV2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawLightningV2Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawLightningV2Client
        """
        return self._raw_client

    def synthesize_lightningv2speech(
        self,
        *,
        text: str,
        voice_id: str,
        sample_rate: typing.Optional[SampleRate] = OMIT,
        speed: typing.Optional[float] = OMIT,
        consistency: typing.Optional[float] = OMIT,
        similarity: typing.Optional[float] = OMIT,
        enhancement: typing.Optional[float] = OMIT,
        language: typing.Optional[Lightningv2RequestLanguage] = OMIT,
        output_format: typing.Optional[Lightningv2RequestOutputFormat] = OMIT,
        pronunciation_dicts: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[bytes]:
        """
        Get speech for given text using the Waves API

        Parameters
        ----------
        text : str
            The text to convert to speech.

        voice_id : str
            The voice identifier to use for speech generation.

        sample_rate : typing.Optional[SampleRate]
            The sample rate for the generated audio.

        speed : typing.Optional[float]
            The speed of the generated speech.

        consistency : typing.Optional[float]
            This parameter controls word repetition and skipping. Decrease it to prevent skipped words, and increase it to prevent repetition.

        similarity : typing.Optional[float]
            This parameter controls the similarity between the generated speech and the reference audio. Increase it to make the speech more similar to the reference audio.

        enhancement : typing.Optional[float]
            Enhances speech quality at the cost of increased latency.

        language : typing.Optional[Lightningv2RequestLanguage]
            Determines how numbers are spelled out. If set to 'en', numbers will be read as individual digits in English. If set to 'hi', numbers will be read as individual digits in Hindi.

        output_format : typing.Optional[Lightningv2RequestOutputFormat]
            The format of the output audio.

        pronunciation_dicts : typing.Optional[typing.Sequence[str]]
            The IDs of the pronunciation dictionaries to use for speech generation.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[bytes]
            Synthesized speech retrieved successfully.

        Examples
        --------
        from smallestai import SmallestAI

        client = SmallestAI(
            token="YOUR_TOKEN",
        )
        client.waves.lightning_v2.synthesize_lightningv2speech(
            text="text",
            voice_id="voice_id",
        )
        """
        with self._raw_client.synthesize_lightningv2speech(
            text=text,
            voice_id=voice_id,
            sample_rate=sample_rate,
            speed=speed,
            consistency=consistency,
            similarity=similarity,
            enhancement=enhancement,
            language=language,
            output_format=output_format,
            pronunciation_dicts=pronunciation_dicts,
            request_options=request_options,
        ) as r:
            yield from r.data

    def stream_lightningv2speech(
        self,
        *,
        text: str,
        voice_id: str,
        sample_rate: typing.Optional[SampleRate] = OMIT,
        speed: typing.Optional[float] = OMIT,
        consistency: typing.Optional[float] = OMIT,
        similarity: typing.Optional[float] = OMIT,
        enhancement: typing.Optional[float] = OMIT,
        language: typing.Optional[Lightningv2RequestLanguage] = OMIT,
        output_format: typing.Optional[Lightningv2RequestOutputFormat] = OMIT,
        pronunciation_dicts: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[typing.Any]:
        """
        The Lightning v2 SSE API provides real-time text-to-speech streaming capabilities with high-quality voice synthesis. This API uses Server-Sent Events (SSE) to deliver audio chunks as they're generated, enabling low-latency audio playback without waiting for the entire audio file to process.
        For an end-to-end example of how to use the Lightning v2 SSE API, check out [Text to Speech (SSE) Example](https://github.com/smallest-inc/waves-examples/blob/main/lightning_v2/http_streaming/http_streaming_api.py)

        ## When to Use

        - **Interactive Applications**: Perfect for chatbots, virtual assistants, and other applications requiring immediate voice responses
        - **Long-Form Content**: Efficiently stream audio for articles, stories, or other long-form content without buffering delays
        - **Voice User Interfaces**: Create natural-sounding voice interfaces with minimal perceived latency
        - **Accessibility Solutions**: Provide real-time audio versions of written content for users with visual impairments

        ## How It Works

        1. **Make a POST Request**: Send your text and voice settings to the API endpoint
        2. **Receive Audio Chunks**: The API processes your text and streams audio back as base64-encoded chunks with 1024 byte size
        3. **Process the Stream**: Handle the SSE events to decode and play audio chunks sequentially
        4. **End of Stream**: The API sends a completion event when all audio has been delivered

        Parameters
        ----------
        text : str
            The text to convert to speech.

        voice_id : str
            The voice identifier to use for speech generation.

        sample_rate : typing.Optional[SampleRate]
            The sample rate for the generated audio.

        speed : typing.Optional[float]
            The speed of the generated speech.

        consistency : typing.Optional[float]
            This parameter controls word repetition and skipping. Decrease it to prevent skipped words, and increase it to prevent repetition.

        similarity : typing.Optional[float]
            This parameter controls the similarity between the generated speech and the reference audio. Increase it to make the speech more similar to the reference audio.

        enhancement : typing.Optional[float]
            Enhances speech quality at the cost of increased latency.

        language : typing.Optional[Lightningv2RequestLanguage]
            Determines how numbers are spelled out. If set to 'en', numbers will be read as individual digits in English. If set to 'hi', numbers will be read as individual digits in Hindi.

        output_format : typing.Optional[Lightningv2RequestOutputFormat]
            The format of the output audio.

        pronunciation_dicts : typing.Optional[typing.Sequence[str]]
            The IDs of the pronunciation dictionaries to use for speech generation.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.Iterator[typing.Any]
            Synthesized speech retrieved successfully.

        Examples
        --------
        from smallestai import SmallestAI

        client = SmallestAI(
            token="YOUR_TOKEN",
        )
        response = client.waves.lightning_v2.stream_lightningv2speech(
            text="text",
            voice_id="voice_id",
        )
        for chunk in response:
            yield chunk
        """
        with self._raw_client.stream_lightningv2speech(
            text=text,
            voice_id=voice_id,
            sample_rate=sample_rate,
            speed=speed,
            consistency=consistency,
            similarity=similarity,
            enhancement=enhancement,
            language=language,
            output_format=output_format,
            pronunciation_dicts=pronunciation_dicts,
            request_options=request_options,
        ) as r:
            yield from r.data


class AsyncLightningV2Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawLightningV2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawLightningV2Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawLightningV2Client
        """
        return self._raw_client

    async def synthesize_lightningv2speech(
        self,
        *,
        text: str,
        voice_id: str,
        sample_rate: typing.Optional[SampleRate] = OMIT,
        speed: typing.Optional[float] = OMIT,
        consistency: typing.Optional[float] = OMIT,
        similarity: typing.Optional[float] = OMIT,
        enhancement: typing.Optional[float] = OMIT,
        language: typing.Optional[Lightningv2RequestLanguage] = OMIT,
        output_format: typing.Optional[Lightningv2RequestOutputFormat] = OMIT,
        pronunciation_dicts: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[bytes]:
        """
        Get speech for given text using the Waves API

        Parameters
        ----------
        text : str
            The text to convert to speech.

        voice_id : str
            The voice identifier to use for speech generation.

        sample_rate : typing.Optional[SampleRate]
            The sample rate for the generated audio.

        speed : typing.Optional[float]
            The speed of the generated speech.

        consistency : typing.Optional[float]
            This parameter controls word repetition and skipping. Decrease it to prevent skipped words, and increase it to prevent repetition.

        similarity : typing.Optional[float]
            This parameter controls the similarity between the generated speech and the reference audio. Increase it to make the speech more similar to the reference audio.

        enhancement : typing.Optional[float]
            Enhances speech quality at the cost of increased latency.

        language : typing.Optional[Lightningv2RequestLanguage]
            Determines how numbers are spelled out. If set to 'en', numbers will be read as individual digits in English. If set to 'hi', numbers will be read as individual digits in Hindi.

        output_format : typing.Optional[Lightningv2RequestOutputFormat]
            The format of the output audio.

        pronunciation_dicts : typing.Optional[typing.Sequence[str]]
            The IDs of the pronunciation dictionaries to use for speech generation.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[bytes]
            Synthesized speech retrieved successfully.

        Examples
        --------
        import asyncio

        from smallestai import AsyncSmallestAI

        client = AsyncSmallestAI(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.waves.lightning_v2.synthesize_lightningv2speech(
                text="text",
                voice_id="voice_id",
            )


        asyncio.run(main())
        """
        async with self._raw_client.synthesize_lightningv2speech(
            text=text,
            voice_id=voice_id,
            sample_rate=sample_rate,
            speed=speed,
            consistency=consistency,
            similarity=similarity,
            enhancement=enhancement,
            language=language,
            output_format=output_format,
            pronunciation_dicts=pronunciation_dicts,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk

    async def stream_lightningv2speech(
        self,
        *,
        text: str,
        voice_id: str,
        sample_rate: typing.Optional[SampleRate] = OMIT,
        speed: typing.Optional[float] = OMIT,
        consistency: typing.Optional[float] = OMIT,
        similarity: typing.Optional[float] = OMIT,
        enhancement: typing.Optional[float] = OMIT,
        language: typing.Optional[Lightningv2RequestLanguage] = OMIT,
        output_format: typing.Optional[Lightningv2RequestOutputFormat] = OMIT,
        pronunciation_dicts: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[typing.Any]:
        """
        The Lightning v2 SSE API provides real-time text-to-speech streaming capabilities with high-quality voice synthesis. This API uses Server-Sent Events (SSE) to deliver audio chunks as they're generated, enabling low-latency audio playback without waiting for the entire audio file to process.
        For an end-to-end example of how to use the Lightning v2 SSE API, check out [Text to Speech (SSE) Example](https://github.com/smallest-inc/waves-examples/blob/main/lightning_v2/http_streaming/http_streaming_api.py)

        ## When to Use

        - **Interactive Applications**: Perfect for chatbots, virtual assistants, and other applications requiring immediate voice responses
        - **Long-Form Content**: Efficiently stream audio for articles, stories, or other long-form content without buffering delays
        - **Voice User Interfaces**: Create natural-sounding voice interfaces with minimal perceived latency
        - **Accessibility Solutions**: Provide real-time audio versions of written content for users with visual impairments

        ## How It Works

        1. **Make a POST Request**: Send your text and voice settings to the API endpoint
        2. **Receive Audio Chunks**: The API processes your text and streams audio back as base64-encoded chunks with 1024 byte size
        3. **Process the Stream**: Handle the SSE events to decode and play audio chunks sequentially
        4. **End of Stream**: The API sends a completion event when all audio has been delivered

        Parameters
        ----------
        text : str
            The text to convert to speech.

        voice_id : str
            The voice identifier to use for speech generation.

        sample_rate : typing.Optional[SampleRate]
            The sample rate for the generated audio.

        speed : typing.Optional[float]
            The speed of the generated speech.

        consistency : typing.Optional[float]
            This parameter controls word repetition and skipping. Decrease it to prevent skipped words, and increase it to prevent repetition.

        similarity : typing.Optional[float]
            This parameter controls the similarity between the generated speech and the reference audio. Increase it to make the speech more similar to the reference audio.

        enhancement : typing.Optional[float]
            Enhances speech quality at the cost of increased latency.

        language : typing.Optional[Lightningv2RequestLanguage]
            Determines how numbers are spelled out. If set to 'en', numbers will be read as individual digits in English. If set to 'hi', numbers will be read as individual digits in Hindi.

        output_format : typing.Optional[Lightningv2RequestOutputFormat]
            The format of the output audio.

        pronunciation_dicts : typing.Optional[typing.Sequence[str]]
            The IDs of the pronunciation dictionaries to use for speech generation.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.AsyncIterator[typing.Any]
            Synthesized speech retrieved successfully.

        Examples
        --------
        import asyncio

        from smallestai import AsyncSmallestAI

        client = AsyncSmallestAI(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            response = await client.waves.lightning_v2.stream_lightningv2speech(
                text="text",
                voice_id="voice_id",
            )
            async for chunk in response:
                yield chunk


        asyncio.run(main())
        """
        async with self._raw_client.stream_lightningv2speech(
            text=text,
            voice_id=voice_id,
            sample_rate=sample_rate,
            speed=speed,
            consistency=consistency,
            similarity=similarity,
            enhancement=enhancement,
            language=language,
            output_format=output_format,
            pronunciation_dicts=pronunciation_dicts,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk
