# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

# Backward-compat: v4.3.1 had atoms/audience.py with Audience class
from smallestai.atoms.helpers.audience import Audience  # noqa: F401

