# This file was auto-generated by Fern from our API Definition.

import typing

Lightningv2RequestLanguage = typing.Union[
    typing.Literal[
        "en", "hi", "ta", "kn", "mr", "bn", "gu", "ar", "he", "fr", "de", "pl", "ru", "it", "nl", "es", "sv", "ml", "te"
    ],
    typing.Any,
]
