# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.http_response import AsyncHttpResponse, HttpResponse
from ...core.request_options import RequestOptions
from ...core.unchecked_base_model import construct_type
from ..errors.bad_request_error import BadRequestError
from ..errors.internal_server_error import InternalServerError
from ..errors.unauthorized_error import UnauthorizedError
from .types.post_conversation_outbound_response import PostConversationOutboundResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawCallsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def start_an_outbound_call(
        self,
        *,
        agent_id: str,
        phone_number: str,
        variables: typing.Optional[typing.Dict[str, typing.Any]] = OMIT,
        from_product_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[PostConversationOutboundResponse]:
        """
        Initiates an outbound conversation with a specified agent and phone number.

        Parameters
        ----------
        agent_id : str
            The ID of the agent initiating the conversation

        phone_number : str
            The phone number to call

        variables : typing.Optional[typing.Dict[str, typing.Any]]
            The variables to pass to the conversation

        from_product_id : typing.Optional[str]
            The ID of the product to use for the call (get this from the /product/phone-numbers endpoint)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[PostConversationOutboundResponse]
            Successfully started the outbound conversation
        """
        _response = self._client_wrapper.httpx_client.request(
            "conversation/outbound",
            base_url=self._client_wrapper.get_environment().atoms,
            method="POST",
            json={
                "agentId": agent_id,
                "phoneNumber": phone_number,
                "variables": variables,
                "fromProductId": from_product_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    PostConversationOutboundResponse,
                    construct_type(
                        type_=PostConversationOutboundResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawCallsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def start_an_outbound_call(
        self,
        *,
        agent_id: str,
        phone_number: str,
        variables: typing.Optional[typing.Dict[str, typing.Any]] = OMIT,
        from_product_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[PostConversationOutboundResponse]:
        """
        Initiates an outbound conversation with a specified agent and phone number.

        Parameters
        ----------
        agent_id : str
            The ID of the agent initiating the conversation

        phone_number : str
            The phone number to call

        variables : typing.Optional[typing.Dict[str, typing.Any]]
            The variables to pass to the conversation

        from_product_id : typing.Optional[str]
            The ID of the product to use for the call (get this from the /product/phone-numbers endpoint)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[PostConversationOutboundResponse]
            Successfully started the outbound conversation
        """
        _response = await self._client_wrapper.httpx_client.request(
            "conversation/outbound",
            base_url=self._client_wrapper.get_environment().atoms,
            method="POST",
            json={
                "agentId": agent_id,
                "phoneNumber": phone_number,
                "variables": variables,
                "fromProductId": from_product_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    PostConversationOutboundResponse,
                    construct_type(
                        type_=PostConversationOutboundResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
