# This file was auto-generated by Fern from our API Definition.

import typing

GetConversationResponseDataLogsItemType = typing.Union[
    typing.Literal["telephony_inbound", "telephony_outbound", "chat"], typing.Any
]
