# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .workflow_graph_data_nodes_item_position import WorkflowGraphDataNodesItemPosition


class WorkflowGraphDataNodesItem(UncheckedBaseModel):
    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique identifier for the node
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Type of the node (e.g., default_node, end_call, pre_call_api)
    """

    position: typing.Optional[WorkflowGraphDataNodesItemPosition] = None
    data: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    Node-specific data and configuration
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
