# This file was auto-generated by Fern from our API Definition.

import typing

GetWavesVoicesRequestModel = typing.Union[
    typing.Literal["lightning", "lightning-large", "lightning-v2", "lightning-v3.1"], typing.Any
]
