TTSLanguages_lightning = ["en", "hi"]
TTSLanguages_lightning_large = ["en", "hi"]
TTSLanguages_lightning_v2 = ["en", "hi", "mr", "kn", "ta", "bn", "gu", "de", "fr", "es", "it", "pl", "nl", "ru", "ar", "he"]
TTSModels = [
    "lightning",
    "lightning-large",
    "lightning-v2"
]
ASRLanguages_lightning = [
    "it", "es", "en", "pt", "hi", "de", "fr", "uk", "ru", "kn", "ml", "pl",
    "mr", "gu", "cs", "sk", "te", "or", "nl", "bn", "lv", "et", "ro", "pa",
    "fi", "sv", "bg", "ta", "hu", "da", "lt", "mt", "multi"
]
ASRModels = [
    "lightning"
]