# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.serialization import FieldMetadata
from ....core.unchecked_base_model import UncheckedBaseModel
from .post_webhook_request_events_item_event_type import PostWebhookRequestEventsItemEventType


class PostWebhookRequestEventsItem(UncheckedBaseModel):
    agent_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="agentId"),
        pydantic.Field(alias="agentId", description="The ID of the agent"),
    ] = None
    event_type: typing_extensions.Annotated[
        typing.Optional[PostWebhookRequestEventsItemEventType],
        FieldMetadata(alias="eventType"),
        pydantic.Field(alias="eventType", description="The type of event to subscribe to"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
