# This file was auto-generated by Fern from our API Definition.

import typing

PatchAgentIdRequestSynthesizerVoiceConfigOneModel = typing.Union[
    typing.Literal["waves", "waves_lightning_large"], typing.Any
]
