# This file was auto-generated by Fern from our API Definition.

import typing

KnowledgeBaseItemProcessingStatus = typing.Union[
    typing.Literal["pending", "processing", "completed", "failed"], typing.Any
]
