# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel


class TranscriptionResult(UncheckedBaseModel):
    session_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique identifier for the transcription session
    """

    transcript: typing.Optional[str] = pydantic.Field(default=None)
    """
    Transcribed text
    """

    full_transcript: typing.Optional[str] = pydantic.Field(default=None)
    """
    Complete transcription accumulated
    """

    is_final: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Final transcription flag
    """

    is_last: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Last transcription flag
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
