# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .agent_dto_language_enabled import AgentDtoLanguageEnabled
from .agent_dto_language_switching import AgentDtoLanguageSwitching


class AgentDtoLanguage(UncheckedBaseModel):
    """
    The language configuration of the agent
    """

    enabled: typing.Optional[AgentDtoLanguageEnabled] = pydantic.Field(default=None)
    """
    The language of the agent
    """

    switching: typing.Optional[AgentDtoLanguageSwitching] = pydantic.Field(default=None)
    """
    Language switching configuration for the agent
    """

    supported: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The supported languages of the agent
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
