# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .single_prompt_config_tools_item_variables_extraction_schema_item_type import (
    SinglePromptConfigToolsItemVariablesExtractionSchemaItemType,
)


class SinglePromptConfigToolsItemVariablesExtractionSchemaItem(UncheckedBaseModel):
    name: str = pydantic.Field()
    """
    Name of the variable to extract
    """

    description: str = pydantic.Field()
    """
    Description of what this variable represents
    """

    type: SinglePromptConfigToolsItemVariablesExtractionSchemaItemType = pydantic.Field()
    """
    Data type of the variable
    """

    values: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Required when type is 'enum'. List of possible values
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
