# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel


class StreamingTtsConfig(UncheckedBaseModel):
    """
    Configuration object for streaming TTS synthesis
    """

    voice_id: str = pydantic.Field()
    """
    Voice identifier
    """

    language: typing.Optional[str] = pydantic.Field(default=None)
    """
    Language code
    """

    sample_rate: typing.Optional[int] = pydantic.Field(default=None)
    """
    Audio sample rate in Hz
    """

    speed: typing.Optional[float] = pydantic.Field(default=None)
    """
    Speech speed multiplier
    """

    consistency: typing.Optional[float] = pydantic.Field(default=None)
    """
    Voice consistency parameter
    """

    enhancement: typing.Optional[int] = pydantic.Field(default=None)
    """
    Audio enhancement level
    """

    similarity: typing.Optional[float] = pydantic.Field(default=None)
    """
    Voice similarity parameter
    """

    max_buffer_flush_ms: typing.Optional[int] = pydantic.Field(default=None)
    """
    Maximum buffer time before forcing output
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
