# This file was auto-generated by Fern from our API Definition.

import typing

PostAgentAgentIdWebhookSubscriptionsRequestEventTypesItem = typing.Union[
    typing.Literal["pre-conversation", "post-conversation"], typing.Any
]
