# This file was auto-generated by Fern from our API Definition.

import typing

from .create_agent_request_synthesizer_voice_config_gender import CreateAgentRequestSynthesizerVoiceConfigGender
from .create_agent_request_synthesizer_voice_config_one import CreateAgentRequestSynthesizerVoiceConfigOne

CreateAgentRequestSynthesizerVoiceConfig = typing.Union[
    CreateAgentRequestSynthesizerVoiceConfigGender, CreateAgentRequestSynthesizerVoiceConfigOne
]
