# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.unchecked_base_model import UncheckedBaseModel


class GetCampaignIdResponseDataMetrics(UncheckedBaseModel):
    """
    Campaign performance metrics
    """

    total_participants: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total number of contacts in the campaign audience
    """

    contacts_called: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of unique contacts where call was attempted (statuses IN_PROGRESS, COMPLETED, FAILED, NO_ANSWER)
    """

    contacts_connected: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of unique contacts who answered and had a conversation (status COMPLETED)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
