# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.serialization import FieldMetadata
from ....core.unchecked_base_model import UncheckedBaseModel
from .get_audience_id_members_search_response_data_members_item import GetAudienceIdMembersSearchResponseDataMembersItem
from .get_audience_id_members_search_response_data_search_info import GetAudienceIdMembersSearchResponseDataSearchInfo


class GetAudienceIdMembersSearchResponseData(UncheckedBaseModel):
    members: typing.Optional[typing.List[GetAudienceIdMembersSearchResponseDataMembersItem]] = None
    search_info: typing_extensions.Annotated[
        typing.Optional[GetAudienceIdMembersSearchResponseDataSearchInfo],
        FieldMetadata(alias="searchInfo"),
        pydantic.Field(alias="searchInfo", description="Information about the search performed"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
