# This file was auto-generated by Fern from our API Definition.

import typing

SinglePromptConfigToolsItemType = typing.Union[
    typing.Literal["end_call", "transfer_call", "api_call", "extract_dynamic_variables", "knowledge_base_search"],
    typing.Any,
]
