# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.serialization import FieldMetadata
from ....core.unchecked_base_model import UncheckedBaseModel


class GetClonedVoicesResponseVoicesItem(UncheckedBaseModel):
    display_name: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="displayName"),
        pydantic.Field(alias="displayName", description="Display name for the voice."),
    ]
    accent: typing.Optional[str] = pydantic.Field(default=None)
    """
    Accent of the voice.
    """

    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of tags associated with the voice.
    """

    voice_id: typing_extensions.Annotated[
        str, FieldMetadata(alias="voiceId"), pydantic.Field(alias="voiceId", description="Unique Voice ID.")
    ]
    model: typing.Optional[str] = pydantic.Field(default=None)
    """
    Model used to generate the voice.
    """

    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    Status of the voice generation.
    """

    created_at: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="createdAt"),
        pydantic.Field(alias="createdAt", description="Date and time the voice was created."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
