# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.serialization import FieldMetadata
from ....core.unchecked_base_model import UncheckedBaseModel


class GetConversationResponseDataPagination(UncheckedBaseModel):
    total: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total number of matching call logs
    """

    page: typing.Optional[int] = pydantic.Field(default=None)
    """
    Current page number
    """

    limit: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of items per page (page size)
    """

    has_more: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="hasMore"),
        pydantic.Field(alias="hasMore", description="Whether there are more pages available"),
    ] = None
    total_pages: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="totalPages"),
        pydantic.Field(alias="totalPages", description="Total number of pages"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
