# This file was auto-generated by Fern from our API Definition.

import typing

CreateAgentRequestBackgroundSound = typing.Union[
    typing.Literal["", "office", "cafe", "call_center", "static"], typing.Any
]
