# This file was auto-generated by Fern from our API Definition.

import typing

from .patch_agent_id_request_synthesizer_voice_config_gender import PatchAgentIdRequestSynthesizerVoiceConfigGender
from .patch_agent_id_request_synthesizer_voice_config_one import PatchAgentIdRequestSynthesizerVoiceConfigOne

PatchAgentIdRequestSynthesizerVoiceConfig = typing.Union[
    PatchAgentIdRequestSynthesizerVoiceConfigGender, PatchAgentIdRequestSynthesizerVoiceConfigOne
]
