# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.serialization import FieldMetadata
from ....core.unchecked_base_model import UncheckedBaseModel


class LightningSpeechToTextResponseMetadata(UncheckedBaseModel):
    """
    Metadata about the transcription
    """

    filename: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the audio file
    """

    duration: typing.Optional[float] = pydantic.Field(default=None)
    """
    Duration of the audio file in minutes
    """

    file_size: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="fileSize"),
        pydantic.Field(alias="fileSize", description="Size of the audio file in bytes"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
