# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel


class WebhookEvent(UncheckedBaseModel):
    id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="_id"),
        pydantic.Field(alias="_id", description="The unique identifier for the event"),
    ] = None
    webhook_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="webhookId"),
        pydantic.Field(alias="webhookId", description="The ID of the webhook"),
    ] = None
    event_type: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="eventType"),
        pydantic.Field(alias="eventType", description="The type of event"),
    ] = None
    payload: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    The event payload
    """

    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    The status of the event
    """

    created_at: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="createdAt"),
        pydantic.Field(alias="createdAt", description="The date and time when the event was created"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
