# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.serialization import FieldMetadata
from ....core.unchecked_base_model import UncheckedBaseModel
from .get_audience_id_members_response_data_members_item import GetAudienceIdMembersResponseDataMembersItem


class GetAudienceIdMembersResponseData(UncheckedBaseModel):
    members: typing.Optional[typing.List[GetAudienceIdMembersResponseDataMembersItem]] = None
    total_count: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="totalCount"),
        pydantic.Field(alias="totalCount", description="Total number of members in the audience"),
    ] = None
    total_pages: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="totalPages"),
        pydantic.Field(alias="totalPages", description="Total number of pages available"),
    ] = None
    has_more: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="hasMore"),
        pydantic.Field(alias="hasMore", description="Whether there are more pages available"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
