# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.unchecked_base_model import UncheckedBaseModel
from .get_campaign_id_response_data_campaign import GetCampaignIdResponseDataCampaign
from .get_campaign_id_response_data_events_item import GetCampaignIdResponseDataEventsItem
from .get_campaign_id_response_data_metrics import GetCampaignIdResponseDataMetrics


class GetCampaignIdResponseData(UncheckedBaseModel):
    campaign: typing.Optional[GetCampaignIdResponseDataCampaign] = None
    events: typing.Optional[typing.List[GetCampaignIdResponseDataEventsItem]] = pydantic.Field(default=None)
    """
    Campaign events history
    """

    metrics: typing.Optional[GetCampaignIdResponseDataMetrics] = pydantic.Field(default=None)
    """
    Campaign performance metrics
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
