# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .workflow_graph_data_edges_item import WorkflowGraphDataEdgesItem
from .workflow_graph_data_nodes_item import WorkflowGraphDataNodesItem


class WorkflowGraphData(UncheckedBaseModel):
    """
    Workflow configuration using a node-based graph structure
    """

    nodes: typing.Optional[typing.List[WorkflowGraphDataNodesItem]] = pydantic.Field(default=None)
    """
    Array of workflow nodes
    """

    edges: typing.Optional[typing.List[WorkflowGraphDataEdgesItem]] = pydantic.Field(default=None)
    """
    Array of workflow edges connecting nodes
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
