# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.serialization import FieldMetadata
from ....core.unchecked_base_model import UncheckedBaseModel


class DeleteVoiceCloneResponse(UncheckedBaseModel):
    success: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Status if the voice clone was deleted successfully.
    """

    voice_id: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="voiceId"),
        pydantic.Field(alias="voiceId", description="Voice ID of the deleted voice clone."),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
