# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel


class SinglePromptConfigToolsItemResponseVariablesItem(UncheckedBaseModel):
    variable_name: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="variableName"),
        pydantic.Field(alias="variableName", description="Name of the variable to store the extracted value"),
    ]
    json_path: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="jsonPath"),
        pydantic.Field(alias="jsonPath", description="JSON path to extract the value from response"),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
