# coding: utf-8

# flake8: noqa
"""
    Agent Management API

    API for managing agents, their templates, and call logs

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_delete200_response import AgentAgentIdWebhookSubscriptionsDelete200Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_get200_response import AgentAgentIdWebhookSubscriptionsGet200Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_get404_response import AgentAgentIdWebhookSubscriptionsGet404Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_post201_response import AgentAgentIdWebhookSubscriptionsPost201Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_post400_response import AgentAgentIdWebhookSubscriptionsPost400Response
from smallestai.atoms.models.agent_agent_id_webhook_subscriptions_post_request import AgentAgentIdWebhookSubscriptionsPostRequest
from smallestai.atoms.models.agent_dto import AgentDTO
from smallestai.atoms.models.agent_dto_language import AgentDTOLanguage
from smallestai.atoms.models.agent_dto_language_switching import AgentDTOLanguageSwitching
from smallestai.atoms.models.agent_dto_synthesizer import AgentDTOSynthesizer
from smallestai.atoms.models.agent_dto_synthesizer_voice_config import AgentDTOSynthesizerVoiceConfig
from smallestai.atoms.models.agent_from_template_post200_response import AgentFromTemplatePost200Response
from smallestai.atoms.models.agent_get200_response import AgentGet200Response
from smallestai.atoms.models.agent_get200_response_data import AgentGet200ResponseData
from smallestai.atoms.models.agent_id_delete200_response import AgentIdDelete200Response
from smallestai.atoms.models.agent_id_get200_response import AgentIdGet200Response
from smallestai.atoms.models.agent_id_patch200_response import AgentIdPatch200Response
from smallestai.atoms.models.agent_id_patch_request import AgentIdPatchRequest
from smallestai.atoms.models.agent_id_patch_request_language import AgentIdPatchRequestLanguage
from smallestai.atoms.models.agent_id_patch_request_language_switching import AgentIdPatchRequestLanguageSwitching
from smallestai.atoms.models.agent_id_patch_request_synthesizer import AgentIdPatchRequestSynthesizer
from smallestai.atoms.models.agent_id_patch_request_synthesizer_voice_config import AgentIdPatchRequestSynthesizerVoiceConfig
from smallestai.atoms.models.agent_id_patch_request_synthesizer_voice_config_one_of import AgentIdPatchRequestSynthesizerVoiceConfigOneOf
from smallestai.atoms.models.agent_id_patch_request_synthesizer_voice_config_one_of1 import AgentIdPatchRequestSynthesizerVoiceConfigOneOf1
from smallestai.atoms.models.agent_id_workflow_get200_response import AgentIdWorkflowGet200Response
from smallestai.atoms.models.agent_id_workflow_get200_response_data import AgentIdWorkflowGet200ResponseData
from smallestai.atoms.models.agent_id_workflow_get200_response_data_edges_inner import AgentIdWorkflowGet200ResponseDataEdgesInner
from smallestai.atoms.models.agent_id_workflow_get200_response_data_edges_inner_data import AgentIdWorkflowGet200ResponseDataEdgesInnerData
from smallestai.atoms.models.agent_id_workflow_get200_response_data_edges_inner_marker_end import AgentIdWorkflowGet200ResponseDataEdgesInnerMarkerEnd
from smallestai.atoms.models.agent_id_workflow_get200_response_data_nodes_inner import AgentIdWorkflowGet200ResponseDataNodesInner
from smallestai.atoms.models.agent_id_workflow_get200_response_data_nodes_inner_data import AgentIdWorkflowGet200ResponseDataNodesInnerData
from smallestai.atoms.models.agent_id_workflow_get200_response_data_nodes_inner_data_variables import AgentIdWorkflowGet200ResponseDataNodesInnerDataVariables
from smallestai.atoms.models.agent_id_workflow_get200_response_data_nodes_inner_data_variables_data_inner import AgentIdWorkflowGet200ResponseDataNodesInnerDataVariablesDataInner
from smallestai.atoms.models.agent_id_workflow_get200_response_data_nodes_inner_position import AgentIdWorkflowGet200ResponseDataNodesInnerPosition
from smallestai.atoms.models.agent_id_workflow_get404_response import AgentIdWorkflowGet404Response
from smallestai.atoms.models.agent_template_get200_response import AgentTemplateGet200Response
from smallestai.atoms.models.agent_template_get200_response_data_inner import AgentTemplateGet200ResponseDataInner
from smallestai.atoms.models.api_response import ApiResponse
from smallestai.atoms.models.audience_get200_response import AudienceGet200Response
from smallestai.atoms.models.audience_get200_response_data_inner import AudienceGet200ResponseDataInner
from smallestai.atoms.models.audience_id_delete200_response import AudienceIdDelete200Response
from smallestai.atoms.models.audience_id_delete400_response import AudienceIdDelete400Response
from smallestai.atoms.models.audience_id_get200_response import AudienceIdGet200Response
from smallestai.atoms.models.audience_id_get400_response import AudienceIdGet400Response
from smallestai.atoms.models.audience_id_get403_response import AudienceIdGet403Response
from smallestai.atoms.models.audience_id_get404_response import AudienceIdGet404Response
from smallestai.atoms.models.audience_id_members_delete200_response import AudienceIdMembersDelete200Response
from smallestai.atoms.models.audience_id_members_delete200_response_data import AudienceIdMembersDelete200ResponseData
from smallestai.atoms.models.audience_id_members_delete_request import AudienceIdMembersDeleteRequest
from smallestai.atoms.models.audience_id_members_get200_response import AudienceIdMembersGet200Response
from smallestai.atoms.models.audience_id_members_get200_response_data import AudienceIdMembersGet200ResponseData
from smallestai.atoms.models.audience_id_members_get200_response_data_members_inner import AudienceIdMembersGet200ResponseDataMembersInner
from smallestai.atoms.models.audience_id_members_get400_response import AudienceIdMembersGet400Response
from smallestai.atoms.models.audience_id_members_get500_response import AudienceIdMembersGet500Response
from smallestai.atoms.models.audience_id_members_post200_response import AudienceIdMembersPost200Response
from smallestai.atoms.models.audience_id_members_post200_response_data_inner import AudienceIdMembersPost200ResponseDataInner
from smallestai.atoms.models.audience_id_members_post200_response_data_inner_data import AudienceIdMembersPost200ResponseDataInnerData
from smallestai.atoms.models.audience_id_members_post400_response import AudienceIdMembersPost400Response
from smallestai.atoms.models.audience_id_members_post403_response import AudienceIdMembersPost403Response
from smallestai.atoms.models.audience_id_members_post_request import AudienceIdMembersPostRequest
from smallestai.atoms.models.audience_id_members_search_get200_response import AudienceIdMembersSearchGet200Response
from smallestai.atoms.models.audience_id_members_search_get200_response_data import AudienceIdMembersSearchGet200ResponseData
from smallestai.atoms.models.audience_id_members_search_get200_response_data_search_info import AudienceIdMembersSearchGet200ResponseDataSearchInfo
from smallestai.atoms.models.audience_id_members_search_get400_response import AudienceIdMembersSearchGet400Response
from smallestai.atoms.models.audience_id_members_search_get500_response import AudienceIdMembersSearchGet500Response
from smallestai.atoms.models.audience_post200_response import AudiencePost200Response
from smallestai.atoms.models.audience_post200_response_data import AudiencePost200ResponseData
from smallestai.atoms.models.audience_post400_response import AudiencePost400Response
from smallestai.atoms.models.bad_request_error_response import BadRequestErrorResponse
from smallestai.atoms.models.campaign_get200_response import CampaignGet200Response
from smallestai.atoms.models.campaign_get200_response_data import CampaignGet200ResponseData
from smallestai.atoms.models.campaign_get_request import CampaignGetRequest
from smallestai.atoms.models.campaign_id_get200_response import CampaignIdGet200Response
from smallestai.atoms.models.campaign_id_get200_response_data import CampaignIdGet200ResponseData
from smallestai.atoms.models.campaign_post201_response import CampaignPost201Response
from smallestai.atoms.models.campaign_post_request import CampaignPostRequest
from smallestai.atoms.models.conversation_id_get200_response import ConversationIdGet200Response
from smallestai.atoms.models.conversation_id_get200_response_data import ConversationIdGet200ResponseData
from smallestai.atoms.models.conversation_outbound_post200_response import ConversationOutboundPost200Response
from smallestai.atoms.models.conversation_outbound_post200_response_data import ConversationOutboundPost200ResponseData
from smallestai.atoms.models.conversation_outbound_post_request import ConversationOutboundPostRequest
from smallestai.atoms.models.create_agent_from_template_request import CreateAgentFromTemplateRequest
from smallestai.atoms.models.create_agent_request import CreateAgentRequest
from smallestai.atoms.models.create_agent_request_language import CreateAgentRequestLanguage
from smallestai.atoms.models.create_agent_request_language_synthesizer import CreateAgentRequestLanguageSynthesizer
from smallestai.atoms.models.create_agent_request_language_synthesizer_voice_config import CreateAgentRequestLanguageSynthesizerVoiceConfig
from smallestai.atoms.models.internal_server_error_response import InternalServerErrorResponse
from smallestai.atoms.models.knowledge_base import KnowledgeBase
from smallestai.atoms.models.knowledge_base_item import KnowledgeBaseItem
from smallestai.atoms.models.knowledgebase_get200_response import KnowledgebaseGet200Response
from smallestai.atoms.models.knowledgebase_id_get200_response import KnowledgebaseIdGet200Response
from smallestai.atoms.models.knowledgebase_id_items_get200_response import KnowledgebaseIdItemsGet200Response
from smallestai.atoms.models.knowledgebase_id_items_upload_text_post_request import KnowledgebaseIdItemsUploadTextPostRequest
from smallestai.atoms.models.knowledgebase_post201_response import KnowledgebasePost201Response
from smallestai.atoms.models.knowledgebase_post_request import KnowledgebasePostRequest
from smallestai.atoms.models.organization_get200_response import OrganizationGet200Response
from smallestai.atoms.models.organization_get200_response_data import OrganizationGet200ResponseData
from smallestai.atoms.models.organization_get200_response_data_members_inner import OrganizationGet200ResponseDataMembersInner
from smallestai.atoms.models.organization_get200_response_data_subscription import OrganizationGet200ResponseDataSubscription
from smallestai.atoms.models.product_phone_numbers_get200_response import ProductPhoneNumbersGet200Response
from smallestai.atoms.models.product_phone_numbers_get200_response_data_inner import ProductPhoneNumbersGet200ResponseDataInner
from smallestai.atoms.models.product_phone_numbers_get200_response_data_inner_attributes import ProductPhoneNumbersGet200ResponseDataInnerAttributes
from smallestai.atoms.models.unauthorized_error_reponse import UnauthorizedErrorReponse
from smallestai.atoms.models.user_get200_response import UserGet200Response
from smallestai.atoms.models.user_get200_response_data import UserGet200ResponseData
from smallestai.atoms.models.webhook import Webhook
from smallestai.atoms.models.webhook_agent import WebhookAgent
from smallestai.atoms.models.webhook_event import WebhookEvent
from smallestai.atoms.models.webhook_get200_response import WebhookGet200Response
from smallestai.atoms.models.webhook_get200_response_data import WebhookGet200ResponseData
from smallestai.atoms.models.webhook_id_delete404_response import WebhookIdDelete404Response
from smallestai.atoms.models.webhook_post201_response import WebhookPost201Response
from smallestai.atoms.models.webhook_post_request import WebhookPostRequest
from smallestai.atoms.models.webhook_post_request_events_inner import WebhookPostRequestEventsInner
from smallestai.atoms.models.webhook_subscription import WebhookSubscription
from smallestai.atoms.models.webhook_subscription_populated import WebhookSubscriptionPopulated
