# This file was auto-generated by Fern from our API Definition.

import typing

GetCampaignIdResponseDataCampaignStatus = typing.Union[
    typing.Literal["draft", "scheduled", "running", "paused", "scheduled_for_retry", "completed"], typing.Any
]
