# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.serialization import FieldMetadata
from ....core.unchecked_base_model import UncheckedBaseModel


class GetConversationIdResponseDataVoiceConfigUsed(UncheckedBaseModel):
    """
    The voice configuration that was actually used for this call.
    """

    model: typing.Optional[str] = pydantic.Field(default=None)
    """
    The TTS model used for the call.
    """

    voice_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="voiceId"),
        pydantic.Field(alias="voiceId", description="The voice ID used for the call."),
    ] = None
    gender: typing.Optional[str] = pydantic.Field(default=None)
    """
    The gender of the voice used for the call (e.g., "male", "female").
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
