# This file was auto-generated by Fern from our API Definition.

import typing

GetConversationResponseDataLogsItemStatus = typing.Union[
    typing.Literal["pending", "in_progress", "completed", "failed", "no_answer", "cancelled", "busy"], typing.Any
]
