# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.single_prompt_data import SinglePromptData
from ...types.workflow_graph_data import WorkflowGraphData

GetAgentIdWorkflowResponseDataData = typing.Union[WorkflowGraphData, SinglePromptData]
