# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from .raw_client import AsyncRawVoicesClient, RawVoicesClient
from .types.get_waves_voices_request_model import GetWavesVoicesRequestModel
from .types.get_waves_voices_response import GetWavesVoicesResponse


class VoicesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawVoicesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawVoicesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawVoicesClient
        """
        return self._raw_client

    def get_waves_voices(
        self, model: GetWavesVoicesRequestModel, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetWavesVoicesResponse:
        """
        Get voices supported for a given model using the new Waves API.

        Parameters
        ----------
        model : GetWavesVoicesRequestModel
            The model to use for speech synthesis.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetWavesVoicesResponse
            Voices retrieved successfully.

        Examples
        --------
        from smallestai import SmallestAI

        client = SmallestAI(
            token="YOUR_TOKEN",
        )
        client.waves.voices.get_waves_voices(
            model="lightning",
        )
        """
        _response = self._raw_client.get_waves_voices(model, request_options=request_options)
        return _response.data


class AsyncVoicesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawVoicesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawVoicesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawVoicesClient
        """
        return self._raw_client

    async def get_waves_voices(
        self, model: GetWavesVoicesRequestModel, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetWavesVoicesResponse:
        """
        Get voices supported for a given model using the new Waves API.

        Parameters
        ----------
        model : GetWavesVoicesRequestModel
            The model to use for speech synthesis.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetWavesVoicesResponse
            Voices retrieved successfully.

        Examples
        --------
        import asyncio

        from smallestai import AsyncSmallestAI

        client = AsyncSmallestAI(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.waves.voices.get_waves_voices(
                model="lightning",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_waves_voices(model, request_options=request_options)
        return _response.data
