# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.serialization import FieldMetadata
from ....core.unchecked_base_model import UncheckedBaseModel


class GetAgentTemplateResponseDataItem(UncheckedBaseModel):
    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The ID of the agent template
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the agent template
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    The description of the agent template
    """

    avatar_url: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="avatarUrl"),
        pydantic.Field(alias="avatarUrl", description="The avatar URL of the agent template"),
    ] = None
    reference_url: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="referenceUrl"),
        pydantic.Field(alias="referenceUrl", description="The docs url of the agent template"),
    ] = None
    category: typing.Optional[str] = pydantic.Field(default=None)
    """
    The category of the agent template
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
