# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from .agent_dto_synthesizer_voice_config import AgentDtoSynthesizerVoiceConfig


class AgentDtoSynthesizer(UncheckedBaseModel):
    """
    The synthesizer (TTS) configuration of the agent
    """

    voice_config: typing_extensions.Annotated[
        typing.Optional[AgentDtoSynthesizerVoiceConfig],
        FieldMetadata(alias="voiceConfig"),
        pydantic.Field(alias="voiceConfig", description="The voice configuration of the synthesizer"),
    ] = None
    speed: typing.Optional[float] = pydantic.Field(default=None)
    """
    The speed of the synthesizer
    """

    consistency: typing.Optional[float] = pydantic.Field(default=None)
    """
    The consistency of the synthesizer
    """

    similarity: typing.Optional[float] = pydantic.Field(default=None)
    """
    The similarity of the synthesizer
    """

    enhancement: typing.Optional[float] = pydantic.Field(default=None)
    """
    The enhancement of the synthesizer
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
