# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from .single_prompt_config_tools_item_request_body_schema_properties_value import (
    SinglePromptConfigToolsItemRequestBodySchemaPropertiesValue,
)
from .single_prompt_config_tools_item_request_body_schema_type import SinglePromptConfigToolsItemRequestBodySchemaType


class SinglePromptConfigToolsItemRequestBodySchema(UncheckedBaseModel):
    """
    Optional for api_call type. Schema defining the structure of the request body
    """

    type: SinglePromptConfigToolsItemRequestBodySchemaType
    properties: typing.Dict[str, SinglePromptConfigToolsItemRequestBodySchemaPropertiesValue]
    required: typing.List[str]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
