# This file was auto-generated by Fern from our API Definition.

import typing

SinglePromptConfigToolsItemVariablesExtractionSchemaItemType = typing.Union[
    typing.Literal["text", "number", "boolean", "enum"], typing.Any
]
